from gui.gui import GUI, QtCore, QtGui, QtWidgets, Qt
from read_input import read_polygon, read_disc, read_point
from arr2_epec_seg_ex import *
import math

def point_to_tuple(p):
  return p.x().to_double(), p.y().to_double()

def add_polygon(gui, poly, color):
  lst0 = []
  for point in poly.vertices():
    lst0.append(point_to_tuple(point))
  return gui.add_polygon(lst0, color)

def set_up_scene_ms():
  gui.clear_scene()
  gui.clear_queue()
  bounding_rect = [(0, 0), (0, 1000), (1000, 1000), (1000, 0)]
  gui.add_polygon(bounding_rect, Qt.transparent)
  poly = Polygon_2()
  poly.push_back(Point_2(0, 0))
  poly.push_back(Point_2(100, 0))
  poly.push_back(Point_2(100, 200))

  poly1 = Polygon_2()
  poly1.push_back(Point_2(300, 0))
  poly1.push_back(Point_2(350, 0))
  poly1.push_back(Point_2(350, 50))
  poly1.push_back(Point_2(300, 50))

  p1 = add_polygon(gui, poly1, Qt.red)
  p0 = add_polygon(gui, poly, Qt.blue)

  print(type(minkowski_sum_2(poly, poly1)))
  poly2 = minkowski_sum_2(poly, poly1).outer_boundary()
  print(type(poly2))
  p2 = add_polygon(gui, poly2, Qt.green)
  p2.visible = 0
  anim = gui.visibility_animation(p2, False)
  gui.queue_animation(anim)

  print(p0, *point_to_tuple(poly[0]), *point_to_tuple(poly1[0]))
  anim = gui.linear_translation_animation(p0, *point_to_tuple(poly[0]), *point_to_tuple(poly1[0]), 0)
  gui.queue_animation(anim)
  for i in range(poly1.size()):
    start = point_to_tuple(poly1[i])
    end = point_to_tuple(poly1[(i+1) % (poly.size()+1)])
    anim = gui.linear_translation_animation(p0, *start, *end)
    gui.queue_animation(anim)
  gui.queue_animation(gui.pause_animation(500))

  anim = gui.visibility_animation(p2, True)
  gui.queue_animation(anim)

def set_up_scene_arr():
  gui.clear_scene()
  gui.clear_queue()
  p0 = Point_2(0, 0)
  p1 = Point_2(100, 100)
  p2 = Point_2(0, 100)
  p3 = Point_2(100, 0)
  s0 = Segment_2(p0, p1)
  c0 = Curve_2(s0)
  c1 = Curve_2(Segment_2(p2, p3))
  arr = Arrangement_2()
  insert(arr, c0)
  insert(arr, c1)

  

  for edge in arr.edges():
    p0x = edge.source().point().x().to_double()
    p0y = edge.source().point().y().to_double()
    p1x = edge.target().point().x().to_double()
    p1y = edge.target().point().y().to_double()
    gui.add_segment(p0x, p0y, p1x, p1y, Qt.red)

  disc = gui.add_disc(4, 0, 0)
  for face in arr.faces():
    print(face.number_of_inner_ccbs())
    for ccb in face.inner_ccbs():
      for halfedge in ccb:
        x0 = halfedge.source().point().x().to_double()
        y0 = halfedge.source().point().y().to_double()
        x1 = halfedge.target().point().x().to_double()
        y1 = halfedge.target().point().y().to_double()
        anim = gui.linear_translation_animation(disc, x0, y0, x1, y1, 300)
        gui.queue_animation(anim)

def play_animation():
  gui.play_queue()

poly2 = None
if __name__ == "__main__":
  import sys
  app = QtWidgets.QApplication(sys.argv)
  gui = GUI()
  gui.set_logic(0, set_up_scene_arr)
  gui.set_button_text(0, "arrangement scene")
  gui.set_logic(1, set_up_scene_ms)
  gui.set_button_text(1, "ms scene")
  gui.set_logic(2, play_animation)
  gui.set_button_text(2, "play animation")
  gui.MainWindow.show()
  sys.exit(app.exec_())
